summaryrefslogtreecommitdiffstats
path: root/lib/kofficeui/KoTooluButton.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /lib/kofficeui/KoTooluButton.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficeui/KoTooluButton.h')
-rw-r--r--lib/kofficeui/KoTooluButton.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/lib/kofficeui/KoTooluButton.h b/lib/kofficeui/KoTooluButton.h
index d4c33944..1374f6d2 100644
--- a/lib/kofficeui/KoTooluButton.h
+++ b/lib/kofficeui/KoTooluButton.h
@@ -31,7 +31,7 @@ class KoColorPanel : public TQWidget
Q_OBJECT
TQ_OBJECT
public:
- KoColorPanel( TQWidget* tqparent = 0, const char* name = 0 );
+ KoColorPanel( TQWidget* parent = 0, const char* name = 0 );
virtual ~KoColorPanel();
virtual TQSize tqsizeHint() const;
@@ -40,7 +40,7 @@ public:
enum MenuStyle { Plain, CustomColors };
static TQPopupMenu* createColorPopup( MenuStyle style, const TQColor& defaultColor,
const TQObject* receiver, const char* slot,
- TQWidget* tqparent, const char* name );
+ TQWidget* parent, const char* name );
public slots:
void clear();
@@ -108,7 +108,7 @@ class KoColorPopupProxy : public TQObject
Q_OBJECT
TQ_OBJECT
public:
- KoColorPopupProxy( const TQColor& defaultColor, KoColorPanel* recentColors, TQObject* tqparent, const char* name );
+ KoColorPopupProxy( const TQColor& defaultColor, KoColorPanel* recentColors, TQObject* parent, const char* name );
virtual ~KoColorPopupProxy() {}
void setRecentColorPanel( KoColorPanel* recentColors );
@@ -139,11 +139,11 @@ public:
*
* @param icon Name of icon to load (may be absolute or relative)
* @param id Id of this button
* @param tqparent This button's tqparent
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KoToolButton( const TQString& icon, int id, TQWidget* tqparent,
+ KoToolButton( const TQString& icon, int id, TQWidget* parent,
const char* name = 0L, const TQString& txt = TQString(),
KInstance* _instance = KGlobal::instance() );
@@ -154,11 +154,11 @@ public:
*
* @param icon Name of icon to load (may be absolute or relative)
* @param id Id of this button
* @param tqparent This button's tqparent
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
*/
- KoToolButton( const TQPixmap& pixmap, int id, TQWidget* tqparent,
+ KoToolButton( const TQPixmap& pixmap, int id, TQWidget* parent,
const char* name = 0L, const TQString& txt = TQString() );
virtual ~KoToolButton();
@@ -139,11 +139,11 @@ public:
* @param icon Name of icon to load (may be absolute or relative)
* @param id Id of this button
- * @param tqparent This button's tqparent
+ * @param parent This button's parent
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)
@@ -154,11 +154,11 @@ public:
* @param icon Name of icon to load (may be absolute or relative)
* @param id Id of this button
- * @param tqparent This button's tqparent
+ * @param parent This button's parent
* @param name This button's internal name
* @param txt This button's text (in a tooltip or otherwise)